var map = L.map(document.getElementById('mapDIV'), {
    center: [-20.1438, -44.1301],
    zoom: 11
    });
	
	
	// Base maps
	var basetopo = L.tileLayer('https://basemap.nationalmap.gov/arcgis/rest/services/USGSTopo/MapServer/WMTS/tile/1.0.0/USGSTopo/default/default028mm/{z}/{y}/{x}.png', {});
	var baserelief = L.tileLayer('https://tile.opentopomap.org/{z}/{x}/{y}.png', {});

	basetopo.addTo(map);
	baserelief.addTo(map);
 
    var thetrail = L.geoJSON(trail, {
        color: '#800000',
        weight: 3,
        dashArray: '12 8 12',
    });
    thetrail.bindTooltip('Trilha Brumadinho')
    thetrail.addTo(map);
	
	var towns = L.geoJSON(trail_stops, 
                      {pointToLayer: function(feature, latlng){
                          return L.circleMarker(latlng, {radius: 5, color: '#00008b',
                                                         fillOpacity: 0.5});
                      },
                      onEachFeature: function( feature, layer){
                          var elevation = feature.properties.elev_in_m;
                          var lat = feature.properties.prim_lat_d;
                          var lon = feature.properties.prim_lon_1;
                          

                          layer.bindPopup('<br/>Elevation: ' + elevation +
                                         '<br/>Lat/Lon: ' + lat + ' , ' + lon);
                          layer.on('mouseover', function() {layer.openPopup();});
                          layer.on('mouseout', function() {layer.closePopup();});
                      }
                     });

	towns.addTo(map);
	
	var placer = L.geoPackageFeatureLayer([], {
		  geoPackageUrl: 'code/points.gpkg',
		  layerName: 'points',
		  pointToLayer: function(feature, latlng){
			  return L.circleMarker(latlng, {radius: 5,
											stroke: false,
											fillColor: '#800000',
											fillOpacity: 0.6});
		  },
		  onEachFeature: function( feature, layer){
			  var name = feature.properties.name;			 
			  var lat = feature.properties.prim_lat_d;
			  var lon = feature.properties.prim_lon_1;

			  layer.bindPopup('Name: ' + name +							  
							  '<br/>Lat/Lon: ' + lat + ' , ' + lon);
			  layer.on('mouseover', function() {layer.openPopup();});
			  layer.on('mouseout', function() {layer.closePopup();});
		  }
	  });
  

	
	var baselayers = {
    'Shaded Relief': baserelief,
    'National Map': basetopo
	};
	var overlays = {
		'The Trail': thetrail,
		'Towns': towns,
		'Points': placer
	};
	L.control.layers(baselayers, overlays).addTo(map);
	
	// Add scalebar

	var scale = L.control.scale()
	scale.addTo(map)

	// Add attribution
	map.attributionControl.addAttribution('National Map Topo');
	map.attributionControl.addAttribution('OpenTopoMap');